"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateOutput = void 0;
const puppeteer_1 = __importDefault(require("puppeteer"));
const is_http_url_1 = require("./is-http-url");
async function generateOutput(html, relativePath, config) {
    const browser = await puppeteer_1.default.launch(Object.assign({ devtools: config.devtools }, config.launch_options));
    const page = await browser.newPage();
    // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
    await page.goto(`http://localhost:${config.port}${relativePath}`); // make sure relative paths work as expected
    await page.setContent(html); // overwrite the page content with what was generated from the markdown
    for (const stylesheet of config.stylesheet) {
        await page.addStyleTag(is_http_url_1.isHttpUrl(stylesheet) ? { url: stylesheet } : { path: stylesheet });
    }
    if (config.css) {
        await page.addStyleTag({ content: config.css });
    }
    for (const scriptTagOptions of config.script) {
        await page.addScriptTag(scriptTagOptions);
    }
    /**
     * Trick to wait for network to be idle.
     *
     * @todo replace with page.waitForNetworkIdle once exposed
     * @see https://github.com/GoogleChrome/puppeteer/issues/3083
     */
    await Promise.all([
        page.waitForNavigation({ waitUntil: 'networkidle0' }),
        page.evaluate(() => history.pushState(undefined, '', '#')) /* eslint no-undef: off */,
    ]);
    let outputFileContent = '';
    if (config.devtools) {
        await new Promise((resolve) => page.on('close', resolve));
    }
    else if (config.as_html) {
        outputFileContent = await page.content();
    }
    else {
        await page.emulateMediaType(config.page_media_type);
        outputFileContent = await page.pdf(config.pdf_options);
    }
    await browser.close();
    return config.devtools ? undefined : { filename: config.dest, content: outputFileContent };
}
exports.generateOutput = generateOutput;
